#
# spec file for package yast2-smt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yast2-smt
Version:        3.0.16
Release:        2.6.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        yast2-smt-%{version}.tar.bz2

Prefix:         /usr

Requires:       yast2
# FATE 305541: Creating NCCcredentials file using yast2-registration
Requires:       /bin/hostname
Requires:       /usr/bin/curl
Requires:       /usr/bin/grep
Requires:       yast2-registration
# For adjusting the NCCcredentials file permissions
Requires:       /bin/chmod
Requires:       /bin/chown
Requires:       /usr/bin/setfacl
# For checking whether the DB->user is available on the system
Requires:       /usr/bin/getent
Requires:       sudo
# Modified smt-catalogs (added --batch-mode)
# SMT::Client::getPatchStatusLabel returning two values
# don't require SMT (instead ask to install it), but prevent older versions
Conflicts:      smt < 3.0.36
# Icons
Requires:       hicolor-icon-theme
# any YaST theme
Requires:       yast2_theme
# 'current'
PreReq:         yast2-branding

# This YaST tool configures SMT (cron, apache2)
Recommends:     mysql
Recommends:     cron
Recommends:     apache2

# If CA is missing, SMT offers to create one
Recommends:     yast2-ca-management

BuildRequires:  hicolor-icon-theme
BuildRequires:  perl-XML-Writer
BuildRequires:  update-desktop-files
BuildRequires:  yast2
BuildRequires:  yast2-devtools
BuildRequires:  yast2-testsuite
# any YaST theme
BuildRequires:  yast2_theme
# build must not have any choice, using package that provides 'yast2-branding'
%if 0%{?is_opensuse}
BuildRequires:  yast2-branding-openSUSE
%else
BuildRequires:  yast2-branding-SLES
%endif

BuildArch:      noarch

Summary:        Configuration of Subscription Management Tool for SUSE Linux Enterprise
License:        GPL-2.0
Group:          System/YaST

%description
Provides the YaST module for SMT configuration.

%prep
%setup -n yast2-smt-%{version}

%build
%yast_build

%install
%yast_install

for f in `find $RPM_BUILD_ROOT/%{prefix}/share/applications/YaST2/ -name "*.desktop"` ; do
    d=${f##*/}
    %suse_update_desktop_file -d ycc_${d%.desktop} ${d%.desktop}
done

mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/16x16/apps
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/22x22/apps
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/32x32/apps
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/48x48/apps
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/128x128/apps

cd $RPM_BUILD_ROOT//usr/share/YaST2/theme/current/icons
for dir in 16x16 22x22 32x32 48x48 128x128; do
    cd $RPM_BUILD_ROOT/usr/share/icons/hicolor/$dir/apps
    rm -rf yast-smt.png
    ln -s /usr/share/YaST2/theme/current/icons/$dir/apps/yast-smt.png .
done

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%clean
rm -rf "$RPM_BUILD_ROOT"

%files
%defattr(-,root,root)
%dir /usr/share/YaST2/include/smt
/usr/share/YaST2/include/smt/*
/usr/share/YaST2/clients/*.rb
/usr/share/YaST2/modules/SMT*.*
%{prefix}/share/applications/YaST2/smt*.desktop
/usr/share/YaST2/scrconf/smt*.scr
%{prefix}/lib/YaST2/servers_non_y2/ag_*
%{prefix}/lib/YaST2/bin/regsrv-check-creds
%doc %{prefix}/share/doc/packages/yast2-smt
%dir /usr/share/YaST2/control
/usr/share/YaST2/control/smt_control.xml

# ... and icons (again)
# removed, as conflicts with the symlink for current theme
# %dir /usr/share/YaST2/theme/current/icons
%dir /usr/share/YaST2/theme/current/icons/16x16/
%dir /usr/share/YaST2/theme/current/icons/16x16/apps/
%dir /usr/share/YaST2/theme/current/icons/22x22/
%dir /usr/share/YaST2/theme/current/icons/22x22/apps/
%dir /usr/share/YaST2/theme/current/icons/32x32/
%dir /usr/share/YaST2/theme/current/icons/32x32/apps/
%dir /usr/share/YaST2/theme/current/icons/48x48/
%dir /usr/share/YaST2/theme/current/icons/48x48/apps/
%dir /usr/share/YaST2/theme/current/icons/128x128/
%dir /usr/share/YaST2/theme/current/icons/128x128/apps/

/usr/share/YaST2/theme/current/icons/16x16/apps/yast-smt.png
/usr/share/YaST2/theme/current/icons/22x22/apps/yast-smt.png
/usr/share/YaST2/theme/current/icons/32x32/apps/yast-smt.png
/usr/share/YaST2/theme/current/icons/48x48/apps/yast-smt.png
/usr/share/YaST2/theme/current/icons/128x128/apps/yast-smt.png

%dir /usr/share/icons/hicolor/16x16/apps/
%dir /usr/share/icons/hicolor/22x22/apps/
%dir /usr/share/icons/hicolor/32x32/apps/
%dir /usr/share/icons/hicolor/48x48/apps/
%dir /usr/share/icons/hicolor/128x128/apps/

/usr/share/icons/hicolor/16x16/apps/yast-smt.png
/usr/share/icons/hicolor/22x22/apps/yast-smt.png
/usr/share/icons/hicolor/32x32/apps/yast-smt.png
/usr/share/icons/hicolor/48x48/apps/yast-smt.png
/usr/share/icons/hicolor/128x128/apps/yast-smt.png

# client status icons
%dir /usr/share/icons/hicolor/16x16/status
/usr/share/icons/hicolor/16x16/status/client-*.xpm
/usr/share/icons/hicolor/16x16/status/repo-*.xpm
/usr/share/icons/hicolor/16x16/status/patch-*.xpm

%changelog
* Mon Nov 12 2018 jsrain@suse.cz
- re-create icon cache after (un-)installation (bsc#1099938)
- 3.0.16
* Fri Sep  7 2018 jsrain@suse.cz
- added icon 128x128 (bsc#1099938)
- 3.0.15
* Mon Jul 16 2018 ikapelyukhin@suse.com
- Remove cron job rescheduling (bsc#1097560)
- 3.0.14
* Mon May 22 2017 jsrain@suse.cz
- added missing translation marks (bsc#1037811)
- 3.0.13
* Thu Mar  2 2017 jsrain@suse.cz
- explicitly mention "Organization Credentials" (fate#321759)
- rearrange the SMT set-up dialog (bsc#977043)
- 3.0.12
* Fri Jan 20 2017 jsrain@suse.cz
- fixed mirroring custom repositories (bsc#1019551)
- make the Filter button default (bsc#1006984)
- 3.0.11
* Thu Dec 22 2016 jsrain@suse.cz
- prevent exiting the repo selection dialog via hitting Enter in
  the repository filter (bsc#1006984)
- report when error occurres during repo mirroring (bsc#1006989)
- 3.0.10
* Thu Mar 17 2016 jsrain@localhost
- use TextEntry-based filter for repos (fate#319777)
- 3.0.9
* Wed Mar  9 2016 jsrain@localhost
- adjust correct file when defining scheduled jobs (bsc#966898)
- 3.0.8
* Fri Mar  4 2016 jsrain@localhost
- only set Apache server flag SSL when there is a certificate
  (bsc#956632)
- 3.0.7
* Mon Nov 23 2015 jsrain@suse.cz
- fixed detection whether system is registered when configuring
  SMT (bsc#956249)
- 3.0.6
* Fri Oct 16 2015 jsrain@suse.cz
- store created server certificate when it is created while saving
  SMT server settings (bsc#950692)
- 3.0.5
* Fri Sep 25 2015 jsrain@suse.cz
- adjusted several texts (bsc#947276)
- 3.0.4
* Thu Sep 10 2015 jsrain@suse.cz
- check for correct certificate file name (bsc#945081)
- 3.0.3
* Fri Sep  4 2015 jsrain@suse.cz
- do not require smt, install it on demand instead (bsc#944479)
- re-add initial configuration wizard (bsc#944491)
- fixed the systemd target to enable/check (bsc#944499)
- 3.0.2
* Fri Jul 24 2015 jsrain@suse.cz
- clean-up NCC support
- 3.0.1
* Wed May 27 2015 jsrain@suse.cz
- updated to SLE12
- 3.0.0
* Thu Nov 13 2014 jsrain@suse.cz
- when migration not possible, show the reason (bnc#903787)
- 2.17.31
* Wed Oct  8 2014 jsrain@suse.cz
- corrected the license of the package
* Wed Oct  1 2014 jsrain@suse.cz
- 2.17.30
- adjust default download server for SCC
* Mon Jul  7 2014 mc@suse.de
- 2.17.29
- Comments always start at the beginning of a line (bnc#881728)
* Thu Jun 12 2014 jsrain@suse.cz
- improved confusing wording when aborging repo mirroring
  (bnc#857206)
* Mon May 26 2014 jsrain@suse.cz
- adapted to work also against SCC
- 2.17.28
* Mon Apr 15 2013 mc@suse.de
- Require sudo to test file access (bnc#815235)
- 2.17.27
* Wed Apr  3 2013 jsrain@suse.cz
- allow to configure CA management when configuring SMT during
  firstboot (bnc#812930)
- 2.17.26
* Wed Feb  8 2012 mc@suse.de
- 2.17.25
- fix label text cut off (bnc#745861)
* Wed Jan 25 2012 mc@suse.de
- strip trailing whitespaces from url and username/password
  (bnc#trailing)
* Fri Jan 20 2012 mc@suse.de
- implement staging groups (FATE#308764)
* Wed Sep 28 2011 mc@suse.de
- 2.17.24
- modify credentials test to work also with a
  SLMS registration server (bnc#549481)
- make registration and download url configurable
* Fri Mar  4 2011 dmueller@suse.de
- require latest smt version
* Mon Feb 14 2011 locilka@suse.cz
- Fixed ag_smt to build a version using epo, rel and ver and drop
  epo, rel, ver to prevent from Perl->YCP conversion errors while
  parsing patch details (BNC #670654).
- 2.17.23
* Mon Apr 19 2010 mc@suse.de
- fix staging for yum repos (bnc#587606)
* Wed Jan 20 2010 mc@suse.de
- use the database for staging (bnc#572170)
* Wed Nov 18 2009 locilka@suse.cz
- Fixed 'timestamps are off by one month' (bnc #537087).
- 2.17.22
* Fri Jul 10 2009 locilka@suse.cz
- Checking for permissions for mirrored repositories has been moved
  to the end of writing the configuration (database is already
  running) (bnc #521013).
- 2.17.21
* Thu Jul  9 2009 locilka@suse.cz
- Added support for Job Queue Cleanup script and additional support
  for scripts possibly added in the future or manually added by
  user (bnc #520557).
- 2.17.20
* Wed Jul  8 2009 locilka@suse.cz
- Checking and adjusting owner and permissions on directory where
  repositories are mirrored (bnc #520245).
- Fixed checking for smt-support being installed in order to offer
  to configure and list it in UI (bnc #520289).
- 2.17.19
* Wed Jul  8 2009 locilka@suse.cz
- Checking for http:// or https:// in SMT Server URL (bnc #518222).
- 2.17.18
* Tue Jul  7 2009 locilka@suse.cz
- Cleaning-up repository cache after mirroring (bnc #519216).
- Help text for staging adjusted to the current UI state.
- Checking for robots.txt, reporting if the file exists (and does
  not contain 'Allow: /repo/keys') (bnc #517264).
* Thu Jul  2 2009 locilka@suse.cz
- Showing the last date of snapshot creation.
* Thu Jul  2 2009 locilka@suse.cz
- Fixed SCR agent to be able to switch repository staging again.
- 2.17.17
* Wed Jul  1 2009 locilka@suse.cz
- Added patch-status icons.
- For 'production' snapshot, 'testing' snapshot is always used as
  a source repository (with no additional filters in use).
- Using new patch-status icons in UI: allowed, forbidded,
  to-be-allowed, and to-be-forbidden.
- 2.17.16
* Tue Jun 23 2009 locilka@suse.cz
- Selective mirroring via YaST is logged into the default location
  /var/log/smt/smt-mirroring.log (bnc #513169).
- Enhanced SMT Server URL fallback (bnc #514304).
- 2.17.15
* Fri Jun 19 2009 jkupec@suse.cz
- respect MirrorSRC smt.conf option when creating
  testing/production snapshots (bnc #510927)
* Wed Jun 10 2009 locilka@suse.cz
- Better 'Enter passphrase' UI layout.
- 2.17.14
* Tue Jun  9 2009 locilka@suse.cz
- Fixed default sorting of tables and combo boxes (bnc #511256).
- 2.17.13
* Fri Jun  5 2009 locilka@suse.cz
- Better handling in Staging tab if there are no repositories with
  staging option enabled (bnc #510315).
* Thu Jun  4 2009 locilka@suse.cz
- Extended Clients UI to show icons for their statuses.
- Extended Staging UI to show icons for repository status.
- Better checking for which snapshot source can be used.
- 2.17.12
* Wed Jun  3 2009 locilka@suse.cz
- Adapted smt SCR agent and Clients UI to the current client status
  capabilities.
- 2.17.11
* Fri May 29 2009 locilka@suse.cz
- Listing clients with their statuses (FATE #306250).
* Tue May 26 2009 locilka@suse.cz
- Checking the system (permissions) also in installation
  (bnc #507022).
- 2.17.10
* Mon May 25 2009 locilka@suse.cz
- Fixed requires and build-requires.
* Fri May 22 2009 locilka@suse.cz
- Mirroring (creating snapshot) is always forced - even if the
  repository is up-to-date, filters can change the metadata.
- Added checking whether a repository is up to date.
- Showing the repository status in UI.
- 2.17.9
* Thu May 21 2009 locilka@suse.cz
- Fixed RPM conflict using a dependency on yast2_theme that creates
  the 'current' symlink to a current theme (bnc #505624).
- Enhanced key and passphrase handling in smt SCR agent.
- Enabling/disabling buttons that modify the repository status.
- Status 'testing' replaced with 'in snapshot' / 'status'.
- Adjusted help texts.
- Toggling 'mirroring' and 'staging' attributes through SCR.
- Adjusted dependencies (smt-1.1.7).
* Tue May 19 2009 locilka@suse.cz
- Providing more information on the key which is going to be used
  for signing a modified repository.
- Copying .mirror file into a newly created snapshot.
- 2.17.8
* Tue May 19 2009 locilka@suse.cz
- If repository does not allow filtering, 'testing' subrepository
  is used as a source for 'production' if such a snapshot exists,
  otherwise 'full' subrepository is used as a fallback.
- Adapted UI to ask for key passphrase if needed.
* Fri May 15 2009 locilka@suse.cz
- Offering managing filters only if it is available.
- 2.17.7
* Thu May 14 2009 locilka@suse.cz
- Two Perl SCR agents merged into one.
* Wed May 13 2009 locilka@suse.cz
- Forcing default logging behavior in SCR Agents. STDOUT must not
  be used for logging at all.
* Tue May 12 2009 locilka@suse.cz
- Extended SCR agent to enable creating 'testing' and 'production'
  snapshots.
- Added possibility to configure 'smt-support -U' call in cron.
* Mon May 11 2009 locilka@suse.cz
- smt.* renamed to smt-server.*
- Added new smt.ycp and smt.desktop for SMT Management (contains
  Repositories and Staging moved here from smt-server).
* Thu May  7 2009 locilka@suse.cz
- Added new ag_smt_repositories SCR agent (.smt.repositories) to
  use direct access to database instead of using smt-catalogs.
- Added functionality to mirror selected repository directly
  from UI (tab Repositories).
* Wed May  6 2009 locilka@suse.cz
- Using new Repositories.pm from SCR agent, no direct access to
  SQL anymore.
- All Catalogs renamed to Repositories.
* Tue May  5 2009 locilka@suse.cz
- Added possiblity to change Testing status of all listed patches
  at once.
- Fixed SCR agent path to parse the 'full' repository.
- Added helps for Staging and Repositories.
* Thu Apr 30 2009 locilka@suse.cz
- Using 'repository' instead of 'catalog'.
- Added possibility to filter by patch category.
- Using MenuButtons for Staging tab (Filters and Snapshots).
* Wed Apr 29 2009 locilka@suse.cz
- Extended staging SCR agent to check filters by category.
- Extended UI to inform user about category filter used and thus
  being unable to change the patch status.
- Added support for adjusting additional category-based filters.
- Using [Cancel]/[OK] instead of [Abort]/[Finish].
* Tue Apr 28 2009 locilka@suse.cz
- Added displaying details for selected patch.
- Added handling for enabling/disabling patches in testing repo.
- Modified staging SCR agent to read repository local path from
  configuration and database.
* Mon Apr 27 2009 locilka@suse.cz
- New YaST SMT icons (polished FATE #306264).
- Added .smt.staging.patches path handler, some pieces are still
  hard-coded.
- Adapted UI to the current .smt.staging.patches SCR output.
* Fri Apr 24 2009 locilka@suse.cz
- Some tabs are available after the first YaST SMT run only. SMT
  has to be configured, configuration written and SMT synced
  (BNC #496886).
- Added new SCR Agent to handle .smt.staging (FATE #306251).
- Added new Patches tab (FATE #306251).
* Wed Apr 22 2009 locilka@suse.cz
- Added possibility to filter catalogs listed for changing their
  statuses (mirroring, staging).
* Tue Apr 14 2009 locilka@suse.cz
- Using LOCAL->smtUser instead of DB->user user in SMT commands
  to switch to (FATE #305540).
- Using generic access to read all values from smt.conf.
- Linking SMT icons from /usr/share/icons/hicolor/.
- 2.17.6
* Fri Apr 10 2009 locilka@suse.cz
- New "Plugged world" icon (FATE #306264).
- 2.17.5
* Thu Apr  9 2009 locilka@suse.cz
- Added UI interface to handle catalogs states (mirroring, staging)
  (FATE #304491).
- 2.17.4
* Tue Apr  7 2009 locilka@suse.cz
- Checking whether NCCcredentials file exists and offering to call
  registration or generate new credentials (FATE #305540).
- Adjusting NCCcredentials file ACL for the SMT user, changing
  owner and file access as a fallback (FATE #305540).
- Using getent to check whether DB->user exist on the system.
- 2.17.3
* Mon Feb  9 2009 locilka@suse.cz
- Dropping YaST SMT icons as they are already in the default YaST
  theme package.
- 2.17.2
* Tue Feb  3 2009 locilka@suse.cz
- Moving CA-management proposal definition to a special control
  file which is owned by yast2-smt.
- Using new control file to call the CA-management proposal if
  CA is missing.
- 2.17.1
* Wed Jan 21 2009 locilka@suse.cz
- Adapted to SLE 11 code-base.
- 2.17.0
* Fri Jul 18 2008 locilka@suse.cz
- Added "NCC Mirroring Credentials" around NUUser and NUPassword
  entries to make that dialog more obvious (bnc #409349).
* Tue Jun 17 2008 locilka@suse.cz
- Temporarily disabling custom_control_file defined by Dirinstall
  module in contructor. This change enables ProductControl module
  to find the proposal:service in product control file
  (bnc #400782).
- 2.13.19
* Tue Jun  3 2008 locilka@suse.cz
- Reading NetworkDevices configuration after reading SuSEfirewall
  configuration (bnc #396646).
- 2.13.18
* Mon Jun  2 2008 locilka@suse.cz
- Texts proofread by taroth.
- Added yast-SMT icon (bnc #390156).
- 2.13.17
* Mon May 26 2008 locilka@suse.cz
- Better labels for password entries (bnc #390085).
- Headlines for pop-up dialogs (bnc #390085).
- 2.13.16
* Wed May 14 2008 mc@suse.de
- fix log message
* Tue May 13 2008 locilka@suse.cz
- Checking 'smt-db setup' exit code for '5' which means 'database
  already exists' and thus 'smt-db cpw' should be called if smt
  password has been changed. Command 'setup' not only creates the
  database but also creates the user with new password. If database
  exists, user is not created and/or password is not changed
  (bnc #389804).
- 2.13.15
* Wed May  7 2008 locilka@suse.cz
- Writing MySQL root password to a temporary file always when
  requested from user, not only for the first time (bnc #387414).
- 2.13.14
* Wed Apr 30 2008 locilka@suse.cz
- Adjusting default button in dialogs (bnc #384703).
- Adjusting default SetFocus (bnc #385005).
- Adding support for smt-gen-report.
- Registering new SCR agents in the beginning of installation
  client (bnc #384994).
- NUUrl support dropped from UI.
- Added dialog helps (bnc #384705).
- 2.13.13
* Tue Apr 29 2008 locilka@suse.cz
- Changing smt user password after database is created
  (bnc #384348).
- 2.13.12
* Wed Apr 23 2008 locilka@suse.cz
- Added inst_smt script to be called from installation workflow.
- 2.13.11
* Thu Apr 17 2008 locilka@suse.cz
- Added firewall support (http, https).
- Changing the SMT-user password by calling 'smt-db cpw'.
- Randomized cron jobs (daily by random startup time, periodical by
  random register-wait).
- 2.13.10
* Wed Apr 16 2008 locilka@suse.cz
- Enabling service only if not yet enabled.
* Wed Apr 16 2008 locilka@suse.cz
- Calling RunlevelEd to solve smt service runlevel dependencies.
- Adjusted RPM dependencies.
- 2.13.9
* Fri Apr 11 2008 locilka@suse.cz
- Removed SCR agent for my.cnf and functions that were modifying
  the MySQL configuration.
- 2.13.8
* Thu Apr 10 2008 locilka@suse.cz
- If MySQL root password is not set, user is asked to set it. In
  case of smt-user is root, the new smt-user's password is used.
- 2.13.7
* Tue Apr  8 2008 locilka@suse.cz
- Added smt-db call to the Write() function.
- Added SCR agent for handling /etc/my.cnf.
- Fixed location of REPORT/reportEmail.
- 2.13.6
* Mon Mar 31 2008 locilka@suse.cz
- YaST module does not copy the CA certificate anymore, it is
  handled by the init script when starting the server.
- Support for [REPORT] in config file.
* Thu Mar 27 2008 locilka@suse.cz
- LOCAL/url is now mandatory. Reporting error if user does not fill
  it in.
* Wed Mar 26 2008 locilka@suse.cz
- Added support for periodical cron jobs (every M-minute...).
- Added support for more different jobs configured by YaST.
- Added support for LOCAL/url.
- 2.13.5
* Wed Mar 19 2008 locilka@suse.cz
- New feature to modify LOCAL/reportEmail.
- Implemented enabling and disabling SMT directly from YaST module.
* Mon Mar 17 2008 locilka@suse.cz
- Using smt init scrpt from YaST.
- Added new tab dialog with DB password handling.
- Added NCC E-mail text-field.
* Mon Mar 10 2008 locilka@suse.cz
- Moving SMT to Network Services (desktop file, bnc #368097)
* Mon Mar  3 2008 locilka@suse.cz
- Added basic support for enabling/disabling the SMT service.
- 2.13.4
* Tue Jan 29 2008 mc@suse.de
- Using /etc/ssl/certs/YaST-CA.pem instead of
  /etc/ssl/servercerts/servercert.pem
- 2.13.2
* Wed Jan 23 2008 locilka@suse.cz
- Added checking whether cron package is installed. If not, package
  can be installed via YaST itself otherwise are cron settings
  (Scheduled mirroring) disabled.
- Checking for a common CA and copying it to the apache2
  configuration.
- Added a possibility to run CA management (proposal) if the
  certificate does not exist.
* Tue Jan 22 2008 locilka@suse.cz
- Added possibility to add, edit and remove Scheduled Mirroring
  cron jobs.
- Enabling and restarting cron when needed.
* Mon Jan 21 2008 locilka@suse.cz
- Added Scheduled Mirroring (cron) processing functions and UI.
- Running /usr/sbin/smt-ncc-sync at the end of the configuration.
- 2.13.1
* Fri Jan 18 2008 locilka@suse.cz
- Added new agent for reading /etc/cron.d/yast2-smt (SMT cron
  entries).
* Fri Jan 18 2008 locilka@suse.cz
- Added help text
- Changed SCR agent to support sections (NU, DB, ...)
* Wed Jan 16 2008 locilka@suse.cz
- 2.13.0
* Tue Jan 15 2008 locilka@suse.cz
- Added functionality to test the entered credentials.
- Requires: grep & curl
- Adjusting the apache configuration when saving SMT configuration.
- Reloading apache in case of configuration change.
- Enabling apache service if it is not enabled.
* Mon Jan 14 2008 locilka@suse.cz
- Initial version (framework, basic UI).
